Function zainodlib::config::load_config
source · pub fn load_config(file_path: &PathBuf) -> IndexerConfigExpand description
Attempts to load config data from a toml file at the specified path.
pub fn load_config(file_path: &PathBuf) -> IndexerConfigAttempts to load config data from a toml file at the specified path.